@@ -34,9 +34,11 @@ const char *JMPHELP[] = {
 "-interaction=STRING      set interaction mode (STRING=batchmode/nonstopmode/",
 "                          scrollmode/errorstopmode)",
 "-jobname=STRING          set the job name to STRING",
+"-kanji=STRING            set Japanese encoding (STRING=euc|jis|sjis)",
 "-kpathsea-debug=NUMBER   set path searching debugging flags according to",
 "                          the bits of NUMBER",
 "-mem=MEMNAME             use MEMNAME instead of program name or a %& line",
+"-output-directory=DIR    use DIR as the directory to write files to",
 "-progname=STRING         set program (and mem) name to STRING",
 "-parse-first-line        parse of the first line of the input file",
 "-recorder                enable filename recorder",
@@ -53,7 +55,6 @@ NULL
 const_string based_prog_name="DVItoMP";
 /* localization maintainers and bug report address */
 const_string local_maintainer="Hideyuki Suzuki";
-const_string this_bug_address="hideyuki@sat.t.u-tokyo.ac.jp";
 
 const char *PDVITOMPHELP[] = {
 "Usage: pdvitomp [OPTION]... DVIFILE[.dvi] [MPXFILE[.mpx]]",
@@ -62,6 +63,7 @@ const char *PDVITOMPHELP[] = {
 "",
 "-help                  display this help and exit",
 "-version               output version information and exit",
+"-kanji={jis|euc|sjis}  set Japanese encoding",
 NULL
 };
 #endif /* PDVITOMP */
